@@ -87,7 +87,8 @@ def match(expr, start, end, string, tokens):
 
 
 def fail(expr, start, string, cause):
-    print("  Except  " + plain_quote(text(cause)))
+    quoted = plain_quote(text(cause))
+    print("  Except  " + quoted)
 
 
 def quote(value, start=0, length=12):
