@@ -15,7 +15,8 @@ import re
 
 from mo_future import string_types, text, first, long, is_text
 
-from moz_sql_parser.keywords import join_keywords, precedence, binary_ops, RESERVED
+from moz_sql_parser.keywords import join_keywords, precedence, RESERVED
+from moz_sql_parser.utils import binary_ops
 
 VALID = re.compile(r"^[a-zA-Z_]\w*$")
 
@@ -241,6 +242,14 @@ class Formatter:
     def _not_like(self, pair):
         return "{0} NOT LIKE {1}".format(self.dispatch(pair[0]), self.dispatch(pair[1]))
 
+    def _rlike(self, pair):
+        return "{0} RLIKE {1}".format(self.dispatch(pair[0]), self.dispatch(pair[1]))
+
+    def _not_rlike(self, pair):
+        return "{0} NOT RLIKE {1}".format(
+            self.dispatch(pair[0]), self.dispatch(pair[1])
+        )
+
     def _is(self, pair):
         return "{0} IS {1}".format(self.dispatch(pair[0]), self.dispatch(pair[1]))
 
